import { defineConfig, loadEnv } from 'vite'
import { resolve } from 'path'

export default defineConfig(({ mode }) => {
    // Load environment variables with no prefixes
    process.env = { ...process.env, ...loadEnv(mode, process.cwd(), '') }

    console.log(`BASE_URL = "${process.env.BASE_URL}"`)

    return {
        base: process.env.BASE_URL,
        build: {
            rollupOptions: {
                input: {
                    main: resolve(__dirname, 'index.html'),
                    login: resolve(__dirname, 'login/index.html'),
                },
            },
        },
        server: {
            proxy: {
                '/api': {
                    target: 'http://localhost:4000/api',
                    changeOrigin: true,
                    rewrite: path => path.replace(/^\/api/, ''),
                },
            },
        },
    }
})
